@@ -1,40 +1,39 @@
 # -*- coding: utf-8 -*-
 #
 
-import sys
 import os
+import sys
 
 sys.path.insert(0, os.path.abspath("../../"))
 sys.path.insert(0, os.path.abspath("./"))
 
 import limits
+
 from theme_config import *
 
 project = "limits"
 description = "limits is a python library to perform rate limiting with commonly used storage backends"
 copyright = "2021, Ali-Akber Saifee"
-version = release = limits.__version__.split("+")[0]
-
-html_theme_options["description"] = description
-html_theme_options["github_repo"] = "limits"
+version, _ = release, part = limits.__version__.split("+")
 
 html_static_path = ["./_static"]
 html_css_files = [
     "custom.css",
     "https://fonts.googleapis.com/css2?family=Fira+Code:wght@300;400;700&family=Fira+Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
 ]
-html_sidebars = {
-    "**": [
-        "about.html",
-        "searchbox.html",
-        "navigation.html",
-        "relations.html",
-        "donate.html",
-    ]
-}
+
+html_title = f"{project} <small><b style='color: var(--color-brand-primary)'>{{{release}}}</b></small>"
+try:
+    ahead = int(part.rsplit(".")[0])
+    if ahead > 0:
+        html_theme_options["announcement"] = f"""
+        This is a development version. The documentation for the latest version: <b>{release}</b> can be found <a href="/en/stable">here</a>
+        """
+        html_title = f"{project} <small><b style='color: var(--color-brand-primary)'>{{dev}}</b></small>"
+except:
+    pass
 
 extensions = [
-    "alabaster",
     "sphinx.ext.autodoc",
     "sphinx.ext.autosectionlabel",
     "sphinx.ext.autosummary",
@@ -42,8 +41,9 @@ extensions = [
     "sphinx.ext.intersphinx",
     "sphinx.ext.todo",
     "sphinx.ext.viewcode",
+    "sphinxext.opengraph",
     "sphinxcontrib.programoutput",
-    "sphinx_autodoc_typehints",
+    "sphinx_copybutton",
     "sphinx_panels",
     "sphinx_paramlinks",
 ]
@@ -57,7 +57,7 @@ autodoc_default_options = {
 
 add_module_names = False
 autoclass_content = "both"
-
+autodoc_typehints_format = "short"
 autosectionlabel_maxdepth = 3
 autosectionlabel_prefix_document = True
 
